import QtQuick 1.0

Rectangle {

    id: container

    width: 1024
    height: 768

    gradient: Gradient {
        GradientStop { color: "lightgrey"; position: 0.0 }
        GradientStop { color: "grey"; position: 1.0 }
    }

    ListModel {
        id: model

        ListElement {
            label: "Nokia N9"
            image: "images/n9.jpg"
            jackpot: false
        }

        ListElement {
            label: "MeeGo"
            image: "images/meego.jpg"
            jackpot: false
        }

        ListElement {
            label: "HP Veer"
            image: "images/hp-veer.jpg"
            jackpot: false
        }

        ListElement {
            label: "Nemo"
            image: "images/nemo.jpg"
            jackpot: false
        }

        ListElement {
            label: "WeTab"
            image: "images/wetab.jpg"
            jackpot: false
        }

        ListElement {
            label: "GTA04"
            image: "images/gta04.jpg"
            jackpot: false
        }

        ListElement {
            label: "Tizen"
            image: "images/tizen.png"
            jackpot: false
        }


        ListElement {
            label: "Nokia N950"
            image: "images/n950.jpg"
            jackpot: true
        }

        ListElement {
            label: "Mer"
            image: "images/mer.jpg"
            jackpot: false
        }

        ListElement {
            label: "Openmobility"
            image: "images/openmobility.png"
            jackpot: false
            content: "http://www.openmobility.cz/"
        }

        ListElement {
            label: "Touch Book"
            image: "images/touchbook.jpg"
            jackpot: false
        }

//        ListElement {
//            label: "SHR"
//            image: "images/shr.png"
//            jackpot: false
//        }

        ListElement {
            label: "Cordia HD"
            image: "images/cordia.png"
            jackpot: false
        }

        ListElement {
            label: "LinuxAlt"
            image: "images/linuxalt.png"
            jackpot: false
            content: "http://bit.ly/vvSQmT"
        }

        ListElement {
            label: "Qt Quick"
            image: "images/qt-logo.jpg"
            jackpot: false
        }
    }

    Text {
        id: winner
        z: 1

        anchors.centerIn: parent

        text: "WINNER"
        font.pixelSize: 0

        color: "#A00000"
        font.bold: true

        opacity: 0

        SequentialAnimation {
            id: winnerAnimation

            running: false

            ParallelAnimation{
                NumberAnimation { target: winner; property: "opacity"; to: 1.0; duration: 500 }
                NumberAnimation { target: winner; property: "font.pixelSize"; to: 200; duration: 2000; easing: Easing.OutInCubic }

            }
            ParallelAnimation {
                NumberAnimation { target: winner; property: "font.pixelSize"; to: 2000; duration: 1000 }
                NumberAnimation { target: winner; property: "opacity"; to: 0.0; duration: 500 }
            }
        }
    }

    Rectangle {
        id: slide

        z: 1

        width: parent.width - 100
        height: 300

        anchors {
            centerIn: parent

            margins: 20
        }

        color: "white"

        radius: 10

        opacity: 0.0

        Column {
            anchors.centerIn: parent
            spacing: 20
            Row {


                Image {
                    id: slideImage

                    width: 200
                    height: 200

                    clip: true
                }

                Text {
                    id: slideLabelText

                    anchors {
                        verticalCenter: slideImage.verticalCenter
                        left: slideImage.right

                        margins: 40
                    }

                    font.pixelSize: 80
                    font.bold: true
                }


            }
            Text {
                id: slideContentText

                font.pixelSize: 40
            }
        }

        Behavior on opacity {
            NumberAnimation { duration: 1000 }
        }

        MouseArea {
            anchors.fill: parent
            onClicked: hideSlide()
        }
    }

    function showSlide(source, label, content) {
        slide.opacity = 1.0
        flickable.opacity = 0.2
        slideImage.source = source
        slideLabelText.text = label
        if (content == undefined)
            slideContentText.text = ""
        else
            slideContentText.text = content
    }

    function hideSlide() {
        slide.opacity = 0.0
        flickable.opacity = 1.0
    }

    PageHeader {
        id: pageHeader

        Text {
            id: labelText

            z: 1

            anchors.top: parent.top
            anchors.right: parent.right

            anchors.margins: 5

            text: "Open source mobilní hračky"
            font.pixelSize: 40
            font.bold: true

            color: "white"
        }

        MouseArea {
            anchors.fill: parent
            onClicked: Qt.quit()
        }
    }

    Flickable {
        id: flickable

        Behavior on opacity {
            NumberAnimation { duration: 1000 }
        }

        anchors {
            top: pageHeader.bottom
            left: parent.left
            margins: 20
        }

        width: parent.width
        height: parent.height

        clip: true

        contentHeight: 2000

        Row {
            id: numberRow

            anchors.left: charColumn.right
            anchors.leftMargin: 20
            anchors.top: flickable.top

            spacing: 20

            Repeater {
                model: [1, 2, 3, 4, 5]

                Rectangle {
                    width: container.width / 8
                    height: 40
                    color: "#A00000"

                    radius: 10

                    Text {
                        id: numberText

                        anchors.centerIn: parent

                        height: parent.height

                        text: index + 1

                        color: "white"
                        font.bold: true
                        font.pixelSize: 35
                    }
                }
            }
        }

        Column {
            id: charColumn

            anchors.top: theGrid.top

            spacing: 20

            Repeater {
                model: ["A", "B", "C"]

                Rectangle {
                    width: 40
                    height: container.width / 8 + 50
                    color: "#A00000"

                    radius: 10

                    Text {
                        anchors.centerIn: parent

                        text: modelData

                        color: "white"
                        font.bold: true
                        font.pixelSize: 35
                    }
                }
            }
        }

        Grid {
            id: theGrid
            anchors.top: numberRow.bottom
            anchors.topMargin: 20
            anchors.left: charColumn.right
            anchors.leftMargin: 20

            columns: 5
            spacing: 20

            Repeater {
                model: model

                Flipable {
                    id: flipable

                    property bool flipped: false
                    property bool canFlip: true

                    width: container.width / 8
                    height: width + 50

                    MouseArea {
                        anchors.fill: parent
                        onClicked: {

                            if (canFlip) {
                                flipable.flipped = !flipable.flipped;

                                if (jackpot && flipable.flipped)
                                    winnerAnimation.start()

                                if (!flipable.flipped) {
                                    canFlip = false

                                    showSlide(image, label, content)

                                }
                            }

                        }
                    }

                    opacity: (canFlip) ? 1.0 : 0.5

                    Behavior on opacity {
                        NumberAnimation { duration: 1000 }
                    }

                    transform: Rotation {
                        id: rotation
                        origin.x: flipable.width/2
                        origin.y: flipable.height/2
                        axis.x: 0; axis.y: 1; axis.z: 0
                        angle: 0
                    }

                    states: State {
                        name: "back"
                        PropertyChanges { target: rotation; angle: 180 }
                        when: flipable.flipped
                    }

                    transitions: Transition {
                            NumberAnimation { target: rotation; property: "angle"; duration: 500 }
                    }

                    back: Rectangle {
                        width: container.width / 8
                        height: width + 50

                        color: "white"
                        radius: 10

                        Image {
                            anchors.horizontalCenter: parent.horizontalCenter
                            anchors.topMargin: 10
                            anchors.top: parent.top

                            width: parent.width - 10
                            height: width - 10

                            source: "images/Jackpot.gif"
                            visible: jackpot

                            smooth: true

                            opacity: flipable.opacity
                        }
                    }

                    front: Rectangle {
                        width: container.width / 8
                        height: width + 50

                        Image {
                            anchors.horizontalCenter: parent.horizontalCenter
                            anchors.topMargin: 10
                            anchors.top: parent.top

                            width: parent.width - 10
                            height: width - 10

                            source: image

                            smooth: true
                        }

                        Text {
                            anchors.bottom: parent.bottom
                            anchors.horizontalCenter: parent.horizontalCenter

                            text: label
                            font.pixelSize: 17
                            font.bold: true
                        }

                        color: "white"
                        radius: 10
                    }
                }
            }
        }
    }
}
